admin Package
=============

:mod:`admin` Package
--------------------

.. automodule:: camelot.admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`application_admin` Module
-------------------------------

.. automodule:: camelot.admin.application_admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`entity_admin` Module
--------------------------

.. automodule:: camelot.admin.entity_admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`not_editable_admin` Module
--------------------------------

.. automodule:: camelot.admin.not_editable_admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`object_admin` Module
--------------------------

.. automodule:: camelot.admin.object_admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`section` Module
---------------------

.. automodule:: camelot.admin.section
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    camelot.admin.action
    camelot.admin.validator

